@echo OFF
rem  * *******************************************************************
rem  *               STAMLRE1.cmd - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2019 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text   - Create four-across mailing label file
rem  * Author - SimoTime Technologies
rem  * Date   - January 01, 1989
rem  *
rem  * The first step uses the IF EXIST function of Windows to delete
rem  * files created in a previous execution of this script.
rem  *
rem  * The second step illustrates the use of a COBOL program to read
rem  * a VSAM, Keyed Sequential Data Set (KSDS) and creates a sequential
rem  * file of 244 byte, fixed length records.
rem  * The program will omit records with a PO Box as the street address.
rem  * This process also illustates the technique for passing a parameter
rem  * from JCL to COBOL.
rem  *
rem  * The third step illustrates the use the SORT program to
rem  * sort a Sequential file by zip code. Both the SORTIN and SORTOUT
rem  * files are sequential files of 244 byte, fixed length records.
rem  *
rem  * The fourth step illustrates the use of a COBOL program that reads
rem  * the sorted,sequential file and creates a Sequential File formatted
rem  * for four-across mailing labels. The print file is a sequential
rem  * file with 192 byte, fixed length records.
rem  *
rem  * The COBOL program also provides an example of using a two
rem  * dimensional array.
rem  *
rem  * This set of programs will run on a mainframe under MVS or on
rem  * a Personal Computer running Windows and Mainframe Express or
rem  * Net Express by Micro Focus.
rem  *
rem  *                     ************
rem  *                     * STAMLRE1 *
rem  *                     ********cmd*
rem  *                          *
rem  *                     ************
rem  *                     * If EXIST *
rem  *                     *******stmt*
rem  *                          *
rem  *    ************     ************     ************
rem  *    * CUSTMAST *-----* STAMLRC1 *-----* MAILTEMP *
rem  *    ********dat*     ********cbl*     *****dat244*
rem  *                          *  *
rem  *                          *  *        ************
rem  *                          *  ***call*** SIMOROAD *
rem  *                          *           ********cbl*
rem  *                          *                *
rem  *                          *           ************
rem  *                          *           * SIMOPARS *
rem  *                          *           ********cbl*
rem  *                          *
rem  *    ************     ************     ************
rem  *    * MAILTEMP *-----*   SORT   *-----* MAILSORT *
rem  *    *****dat244*     ********utl*     *****dat244*
rem  *                          *
rem  *                          *
rem  *    ************     ************     ************
rem  *    * MAILSORT *-----* STAMLRC2 *-----* MAILTEXT *
rem  *    *****dat244*     ********cbl*     *****dat192*
rem  *                          *
rem  *                          *
rem  *                     ************
rem  *                     *   EOJ    *
rem  *                     ************
rem  *
rem  * *******************************************************************
rem  * Step 1 of 4  Set the global environment variables...
rem  *              Delete any previously created file...
rem  * *******************************************************************
:StaMlrS1
     set CmdName=StaMlrE1
     call ..\Env1BASE %CmdName%
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting JobName %CmdName%, User is %USERNAME%"
     call SimoNOTE "Identify JobStep StaMlrS1, Set Globals, Delete Previous Files"
     set MAILTEMP=%BaseLib1%\DATA\wrk1\MAILTEMP.DAT
     set MAILSORT=%BaseLib1%\DATA\wrk1\MAILSORT.DAT
     set MAILTEXT=%BaseLib1%\DATA\wrk1\MAILTEXT.DAT
     if exist %MAILTEMP% del %MAILTEMP%
     if exist %MAILSORT% del %MAILSORT%
     if exist %MAILTEXT% del %MAILTEXT%
rem  *
rem  * *******************************************************************
rem  * Step 2 of 4  Read KSDS and create Sequential File without PO Boxes
rem  *              The NOPOBOX parameter tells the program not to include
rem  *              records that have PO Box addresses.
rem  * *******************************************************************
:StaMlrS2
     call SimoNOTE "Identify JobStep StaMlrS2, Extract non-PO Boxes"
     set CUSTMAST=%BaseLib1%\DATA\APPL\SIMOTIME.DATA.CUSTMAST.DAT
     run SimoEXEC EXEC STAMLRC1 'NOPOBOX'
     if NOT ERRORLEVEL 0 set JobStatus=0010
     if not "%JobStatus%" == "0000" goto :EojNOK
     if exist %MAILTEMP% call SimoNOTE "Produced DataSet %MAILTEMP%"
rem  *
rem  * *******************************************************************
rem  * Step 3 of 4  Sort by Zip Code...
rem  * *******************************************************************
rem  *
:StaMlrS3
     call SimoNOTE "Identify JobStep StaMlrS3, Sort by Postal Code"
     set SYSOUTSAVE=%SYSOUT%
     set SYSOUT=%BaseLIb1%\LOGS\SYSOUTStaMlrSort.TXT
     set SYSIN=%BaseLib1%\PARMLIB\STAMLRT1.CTL
     set SORTIN=%MAILTEMP%
     set SORTOUT=%MAILSORT%
     MFSORT take %SYSIN% use %SORTIN% RECORD F,244 ORG SQ GIVE %SORTOUT% RECORD F,244 ORG SQ
     if ERRORLEVEL = 1 set JobStatus=0020
     set SYSOUT=%SYSOUTSAVE%
     if not "%JobStatus%" == "0000" goto :EojNOK
     if exist %MAILSORT% call SimoNOTE "Produced DataSet %MAILSORT%"
     if exist %MAILSORT% goto :StaMlrS4
        call SimoNOTE "ABENDING JobStep StaMlrS3, Sort Failure..."
        goto :EojNOK
rem  *
rem  * *******************************************************************
rem  * Step 4 of 4  Read Sorted file, create 4-across mailing label file
rem  *              The program looks for a PARM=n where n is a number
rem  *              from 1-4 specifying the number of labels across a
rem  *              row. If this parameter is missing the default is 4.
rem  * *******************************************************************
rem  *
:StaMlrS4
     call SimoNOTE "Identify JobStep StaMlrS4, Create four across labels"
     run SimoEXEC EXEC STAMLRC2
     if ERRORLEVEL = 1 set JobStatus=0030
     if not "%JobStatus%" == "0000" goto :EojNOK
     goto :StaMlrNormalEOJ
rem  *
:EojNOK
     call SimoNOTE "ABENDING JobName %CmdName%, JobStatus %JobStatus%"
     call SimoNOTE "ABENDING Message JobStatus %JobStatus%"
     goto :StaMlrPause
:StaMlrNormalEOJ
     if exist %MAILTEXT% call SimoNOTE "Produced DataSet %MAILTEXT%"
     call SimoNOTE "Finished JobName %CmdName%"
:StaMlrPause
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
