@echo OFF
rem  * *******************************************************************
rem  *               STAMLRE2.cmd - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2019 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text   - Create 4-across and 1-across mailing label files
rem  * Author - SimoTime Technologies
rem  * Date   - January 01, 1989
rem  *
rem  * The first step uses the IF EXIST function of Windows to delete
rem  * files created in a previous execution of this script.
rem  *
rem  * The second step illustrates the use of a COBOL program to read
rem  * a VSAM, Keyed Sequential Data Set (KSDS) and creates a sequential
rem  * file of 244 byte, fixed length records.
rem  * The program will omit records with a PO Box as the street address.
rem  * This process also illustates the technique for passing a parameter
rem  * from JCL to COBOL.
rem  *
rem  * The third step illustrates the uses a COBOL program that uses the
rem  * callable SORT to sort a Sequential file by postal code.
rem  * The SORTIN and SORTOUT files are sequential files of 244 byte,
rem  * fixed length records.
rem  *
rem  * The fourth step illustrates the use of a COBOL program that reads
rem  * the sorted,sequential file and creates a Sequential File formatted
rem  * for four-across mailing labels. The print file is a sequential
rem  * file with 192 byte, fixed length records.
rem  *
rem  * The fifth step will create one-across mailing labels.
rem  *
rem  * The COBOL program also provides an example of using a two
rem  * dimensional array.
rem  *
rem  * This set of programs will run on a mainframe under MVS or on
rem  * a Personal Computer running Windows and Mainframe Express or
rem  * Net Express by Micro Focus.
rem  *
rem  *                     ************
rem  *                     * StaMlrE2 *
rem  *                     ********cmd*
rem  *                          *
rem  *                     ************
rem  *                     * If EXIST *
rem  *                     *******stmt*
rem  *                          *
rem  *    ************     ************     ************
rem  *    * CUSTMAST *-----* STAMLRC1 *-----* MAILTEMP *
rem  *    ********dat*     ********cbl*     ********dat*
rem  *                          *  *
rem  *                          *  *        ************
rem  *                          *  ***call*** SIMOROAD *
rem  *                          *           ********cbl*
rem  *                          *                *
rem  *                          *           ************
rem  *                          *           * SIMOPARS *
rem  *                          *           ********cbl*
rem  *                          *
rem  *    ************     ************     ************
rem  *    * MAILTEMP *-----* STASRTC1 *-----* MAILSORT *
rem  *    ********dat*     ********cbl*     ********dat*
rem  *                          *
rem  *                          *
rem  *    ************     ************     ************
rem  *    * MAILSORT *-----* STAMLRC2 *-----* MAILTXT4 *
rem  *    ********dat*     ********cbl*     ********dat*
rem  *                          *
rem  *                          *
rem  *    ************     ************     ************
rem  *    * MAILSORT *-----* STAMLRC2 *-----* MAILTXT1 *
rem  *    ********dat*     ********cbl*     ********dat*
rem  *                          *
rem  *                          *
rem  *                     ************
rem  *                     *   EOJ    *
rem  *                     ************
rem  *
rem  * *******************************************************************
rem  * Step 1 of 5  Set the global environment variables...
rem  *              Delete any previously created file...
rem  * *******************************************************************
:StaMlrS1
     call ..\Env1BASE
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
rem  *
     call SimoNOTE "*******************************************************StaMlrE2"
     call SimoNOTE "Starting JobName StaMlrE2, User is %USERNAME%"
     call SimoNOTE "Identify JobStep StaMlrS1, Set Globals, Delete Previous Files"
     set MAILTEMP=%BaseLib1%\DATA\Wrk1\MAILTEMP.DAT
     set MAILSORT=%BaseLib1%\DATA\Wrk1\MAILSORT.DAT
     set MAILTEXT=%BaseLib1%\DATA\Wrk1\MAILTXT4.DAT
     if exist %MAILTEMP% del %MAILTEMP%
     if exist %MAILSORT% del %MAILSORT%
     if exist %MAILTEXT% del %MAILTEXT%
rem  *
rem  * *******************************************************************
rem  * Step 2 of 5  Read KSDS, create Sequential File without PO Boxes
rem  *              The NOPOBOX parameter tells the program not to include
rem  *              records that have PO Box addresses.
rem  * *******************************************************************
:StaMlrS2
     call SimoNOTE "Identify JobStep StaMlrS2, Extract non-PO Boxes"
     set CUSTMAST=%BaseLib1%\DATA\APPL\SIMOTIME.DATA.CUSTMAST.DAT
     run SimoEXEC EXEC STAMLRC1 'NOPOBOX'
     if not ERRORLEVEL = 0 set JobStatus=0002
     if not "%JobStatus%" == "0000" goto :StaMlrABEND
     if exist %MAILTEMP% call SimoNOTE "Produced DataSet %MAILTEMP%"
rem  *
rem  * *******************************************************************
rem  * Step 3 of 5  Sort by Postal Code using COBOL Sort...
rem  * *******************************************************************
rem  *
:StaMlrS3
     call SimoNOTE "Identify JobStep StaMlrS3, Sort by Postal Code"
     run SimoEXEC EXEC STASRTC1
     if not ERRORLEVEL = 0 set JobStatus=0003
     if not "%JobStatus%" == "0000" goto :StaMlrABEND
     if exist %MAILSORT% call SimoNOTE "Produced DataSet %MAILSORT%"
     if exist %MAILSORT% goto :StaMlrS4
        set JobnStatus=0003
        call SimoNOTE "ABENDING JobStep StaMlrS3, Sort Failure..."
        goto :StaMlrABEND
rem  *
rem  * *******************************************************************
rem  * Step 4 of 5  Read Sorted file, create 4-across mailing label file
rem  *              The program looks for a PARM=n where n is a number
rem  *              from 1-4 specifying the number of labels across a
rem  *              row. If this parameter is missing the default is 4.
rem  * *******************************************************************
rem  *
:StaMlrS4
     call SimoNOTE "Identify JobStep StaMlrS4, Create four across labels"
     run SimoEXEC EXEC STAMLRC2
     if not ERRORLEVEL = 0 set JobStatus=0004
     if not "%JobStatus%" == "0000" goto :StaMlrABEND
     if exist %MAILTEXT% call SimoNOTE "Produced DataSet %MAILTEXT%"
rem  *
rem  * *******************************************************************
rem  * Step 5 of 5  Read Sorted file, create 1-across mailing label file
rem  *              The program looks for a PARM=n where n is a number
rem  *              from 1-4 specifying the number of labels across a
rem  *              row. If this parameter is missing the default is 4.
rem  * *******************************************************************
rem  *
:StaMlrS5
     call SimoNOTE "Identify JobStep StaMlrS5, Create one across labels"
     set MAILTEXT=%BaseLib1%\DATA\Wrk1\MAILTXT1.DAT
     if exist %MAILTEXT% del %MAILTEXT%
     run SimoEXEC EXEC STAMLRC2 1
     if not ERRORLEVEL = 0 set JobStatus=0005
     if not "%JobStatus%" == "0000" goto :StaMlrABEND
     if exist %MAILTEXT% call SimoNOTE "Produced DataSet %MAILTEXT%"
     goto :StaMlrNormalEOJ
rem  *
:StaMlrABEND
     call SimoNOTE "ABENDING JobName StaMlrE2"
     call SimoNOTE "ABENDING Message Job Status is %JobStatus%"
     goto :StaMlrPause
:StaMlrNormalEOJ
     call SimoNOTE "Finished JobName StaMlrE2"
:StaMlrPause
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
:EOJ
