//STAMLRJ1 JOB SIMOTIME,ACCOUNT,CLASS=1,MSGCLASS=0,NOTIFY=&SYSUID
//* *******************************************************************
//*       This JCL Member is provided by SimoTime Technologies        *
//*           (C) Copyright 1987-2019 All Rights Reserved             *
//*             Web Site URL:   http://www.simotime.com               *
//*                   e-mail:   helpdesk@simotime.com                 *
//* *******************************************************************
//*
//* Text   - Create four-across mailing label file
//* Author - SimoTime Technologies
//* Date   - January 01, 1989
//*
//* The first step illustrates the use of IEFBR14 and DD statements
//* with the DISP=(MOD,DELETE,DELETE) to delete files.
//*
//* The second step illustrates the use of a COBOL program to read
//* a VSAM, Keyed Sequential Data Set (KSDS) and creates a sequential
//* file the omits the records with a PO Box as the street address.
//* This program also illustates the technique for passing a parameter
//* from JCL to COBOL.
//*
//* The third step illustrates the use the SORT program to
//* sort a Sequential file by zip code.
//*
//* The fourth step illustrates the use of a COBOL program that reads
//* the sorted,sequential file and creates a Sequential File formatted
//* for four-across mailing labels.
//*
//* The COBOL program also provides an example of using a two
//* dimensional array.
//*
//* This set of programs will run on a mainframe under MVS or on
//* a Personal Computer running Windows and Mainframe Express or
//* Net Express by Micro Focus.
//*
//*                     ************
//*                     * STAMLRJ1 *
//*                     ********jcl*
//*                          *
//*                     ************
//*                     * IEFBR14  *
//*                     ********utl*
//*                          *
//*    ************     ************     ************
//*    * CUSTMAST *-----* STAMLRC1 *-----* MAILTEMP *
//*    ********dat*     ********cbl*     ********dat*
//*                          *  *
//*                          *  *        ************
//*                          *  ***call*** SIMOROAD *
//*                          *           ********cbl*
//*                          *                *
//*                          *           ************
//*                          *           * SIMOPARS *
//*                          *           ********cbl*
//*                          *
//*    ************     ************     ************
//*    * MAILTEMP *-----*   SORT   *-----* MAILSORT *
//*    ********dat*  *  ********utl*     ********dat*
//*                  *       *
//*    ************  *       *
//*    * STAMLRT1 ****       *
//*    *******pdsm*          *
//*                          *
//*    ************     ************     ************
//*    * MAILSORT *-----* STAMLRC2 *-----* MAILTEXT *
//*    ********dat*     ********cbl*     ********dat*
//*                          *
//*                          *
//*                     ************
//*                     *   EOJ    *
//*                     ************
//*
//* *******************************************************************
//* Step 1 of 4, Delete any previously created file...
//* *******************************************************************
//*
//JOBSETUP EXEC PGM=IEFBR14
//MAILTEMP DD  DSN=SIMOTIME.DATA.MAILTEMP,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=244,DSORG=PS)
//MAILSORT DD  DSN=SIMOTIME.DATA.MAILSORT,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=244,DSORG=PS)
//MAILTEXT DD  DSN=SIMOTIME.DATA.MAILTEXT,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=192,DSORG=PS)
//*
//* *******************************************************************
//* Step 2 of 4, Read KSDS and create Sequential File without PO Boxes
//*              The PARM=NOPOBOX tells the program not to include
//*              records that have PO Box addresses.
//* *******************************************************************
//*
//ADDRST02 EXEC PGM=STAMLRC1,PARM='NOPOBOX'
//CUSTMAST DD  DSN=SIMOTIME.DATA.CUSTMAST,DISP=SHR
//MAILTEMP DD  DSN=SIMOTIME.DATA.MAILTEMP,DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=244,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
//* *******************************************************************
//* Step 3 of 4, Sort by Zip Code...
//* *******************************************************************
//*
//SORTST03 EXEC PGM=SORT,COND=(0,LT),
//             REGION=1024K
//SYSIN    DD  DSN=SIMOTIME.PDS.PARMLIB(STAMLRT1),DISP=SHR
//SORTIN   DD  DSN=SIMOTIME.DATA.MAILTEMP,DISP=OLD
//SORTWK01 DD  UNIT=SYSDA,SPACE=(CYL,55)
//SORTWK02 DD  UNIT=SYSDA,SPACE=(CYL,55)
//SORTWK03 DD  UNIT=SYSDA,SPACE=(CYL,55)
//SORTOUT  DD  DSN=SIMOTIME.DATA.MAILSORT,DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=244,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
//* *******************************************************************
//* Step 4 of 4, Read Sorted file, create 4-across mailing label file
//*              The program looks for a PARM=n where n is a number
//*              from 1-4 specifying the number of labels across a
//*              row. If this parameter is missing the default is 4.
//* *******************************************************************
//*
//MAILST04 EXEC PGM=STAMLRC2,COND=(0,LT)
//MAILSORT DD  DSN=SIMOTIME.DATA.MAILSORT,DISP=OLD
//MAILTEXT DD  DSN=SIMOTIME.DATA.MAILTEXT,DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=192,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
